Package: partsm
Version: 1.1-5
Date: 2026-05-04
Title: Periodic Autoregressive Time Series Models
Authors@R: 
    c(person(given = "Javier",
             family = "Lopez-de-Lacalle",
             role = c("aut", "cph"),
             email = "javlacalle@yahoo.es"),
      person(given = "Matthieu",
             family = "Stigler",
             role = "cre",
             email = "Matthieu.Stigler@gmail.com",
             comment = c(ORCID = "0000-0002-6802-4290")))
Imports: methods
Depends: R (>= 2.14.0)
Description: Basic functions to fit and predict periodic autoregressive time series models. These models are discussed in the book P.H. Franses (1996) "Periodicity and Stochastic Trends in Economic Time Series", Oxford University Press. Data set analyzed in that book is also provided. NOTE: the package was orphaned during several years. It is now only maintained, but no major enhancements are expected, and the maintainer cannot provide any support. 
License: GPL-2
URL: https://github.com/MatthieuStigler/partsm
NeedsCompilation: no
Packaged: 2026-05-04 11:34:23 UTC; matifou
Author: Javier Lopez-de-Lacalle [aut, cph],
  Matthieu Stigler [cre] (ORCID: <https://orcid.org/0000-0002-6802-4290>)
Maintainer: Matthieu Stigler <Matthieu.Stigler@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-04 13:00:02 UTC
Built: R 4.5.2; ; 2026-05-04 16:58:32 UTC; unix
